@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Base class used by init command."""
+
 from __future__ import annotations
 
 import logging
@@ -29,8 +30,8 @@ from molecule.command.init import scenario
 LOG = logging.getLogger(__name__)
 
 
-@base.click_group_ex()  # type: ignore  # noqa: PGH003
-def init():  # pragma: no cover  # noqa: ANN201
+@base.click_group_ex()
+def init() -> None:  # pragma: no cover
     """Initialize a new scenario."""
 
 
